Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1082)

Unified Diff: mojo/shell/public/cpp/connection.h

Issue 1705323003: ContentHandler -> ShellClientFactory (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delete
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/shell/public/cpp/BUILD.gn ('k') | mojo/shell/public/cpp/content_handler_factory.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/shell/public/cpp/connection.h
diff --git a/mojo/shell/public/cpp/connection.h b/mojo/shell/public/cpp/connection.h
index 84f428b8f3d91e7d939ff6d19200a4fee84d9557..a2f6b772be90e7a022e6c38d32d036bbb8fba9ed 100644
--- a/mojo/shell/public/cpp/connection.h
+++ b/mojo/shell/public/cpp/connection.h
@@ -95,15 +95,17 @@ class Connection {
// been established.
virtual bool GetRemoteApplicationID(uint32_t* remote_id) const = 0;
- // Returns the id of the deepest content handler used in connecting to
+ // Returns the id of the deepest shell client factory used in connecting to
// the application. See GetRemoteApplicationID() for details about the return
- // value. A |content_handler_id| value of Shell::kInvalidApplicationID
- // indicates no content handler was used in connecting to the application.
- virtual bool GetRemoteContentHandlerID(
- uint32_t* content_handler_id) const = 0;
-
- // See description in GetRemoteApplicationID()/GetRemoteContentHandlerID(). If
- // the ids are available, |callback| is run immediately.
+ // value. A |shell_client_factory_id| value of Shell::kInvalidApplicationID
+ // indicates no shell client factory was used in connecting to the
+ // application.
+ virtual bool GetRemoteShellClientFactoryID(
+ uint32_t* shell_client_factory_id) const = 0;
+
+ // See description in GetRemoteApplicationID()/
+ // GetRemoteShellClientFactoryID(). If the ids are available, |callback| is
+ // run immediately.
virtual void AddRemoteIDCallback(const Closure& callback) = 0;
// Returns true if the Shell allows |interface_name| to be exposed to the
« no previous file with comments | « mojo/shell/public/cpp/BUILD.gn ('k') | mojo/shell/public/cpp/content_handler_factory.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698